%**************************************************************************
% This file is part of the MLS-C Library; you can redistribute it and/or 
% modify it under the terms of the GNU Lesser General Public License as 
% published by the Free Software Foundation; either version 3 of the 
% License,or any later version.
% This program is distributed in the hope that it will be useful but 
% WITHOUT ANY WARRANTY; without even the implied warranty of 
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General 
% Public License for more details.
% You should have received a copy of the GNU Lesser General Public License
% along with GNU; see the file COPYING.  If not, write to the Free Software
% Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
% or see <http://www.gnu.org/licenses/>.
%**************************************************************************
% Created by: 
%    E Nadal, M Ouallal, JJ Rodenas, F Chinesta and FJ Fuenmayor
%  
% Release 1.0  
% Date: 18/07/2014
%**************************************************************************
%%
function  CreateMacroToGetMLSdata(ShowUX,ShowVY,OutputXYZ,OutputTopology,ShowSX,ShowSY,ShowSZ,ShowTXY,ShowTXZ,ShowTYZ)
% THIS FUNCTION IS USED TO CREATE THE ANSYS MACRO CONTAINING THE RECOVERED
% STRESS FIELD OBTAINED BY THE MLSCX TECHNIQUE.
% INPUT VARIABLES
%==========================================================================

%   ShowUX,ShowVY,ShowWZ      NODE DISPLACEMENTS IN U, V and W DIRECTION.
%   OutputXYZ                 NODE COORDINATES.
%   OutputTopology            MESH TOPOLOGY.
%   ShowSX,ShowSY,ShowSZ,...
%   ShowTXY,ShowTXZ,ShowTYZ   STRESS COMPONENTS.


    fid = fopen('MLSresults.mac','wt');     % 'wt' means "write text"
    if (fid < 0)
        error('could not open file "MLSresults.mac"');
    end
    
    formatSpec  ='/PREP7   \n';
    fprintf(fid, formatSpec);
    formatSpec  ='ET,1,PLANE182 \n';
    fprintf(fid, formatSpec);
    
    % List of nodes coordinates
    formatSpec  ='N , %4u , %4.16f, %4.16f, %4.16f  \n';
    for i=1:size(OutputXYZ,1)
        fprintf(fid, formatSpec,i,OutputXYZ(i,1),OutputXYZ(i,2)...
                ,OutputXYZ(i,3));
    end
    
    % List for nodes per element
    formatSpec  ='EN , %4u , %4u , %4u , %4u , %4u   \n';
    for i=1:size(OutputTopology,1)
        fprintf(fid,formatSpec,i,OutputTopology(i,1),OutputTopology(i,2)...
                ,OutputTopology(i,3),OutputTopology(i,4));
    end

    % Data introduced to postprocess 
    formatSpec  ='MP,EX,1,1   \n';
    fprintf(fid, formatSpec);

    formatSpec  ='MP,NUXY,1,0.3   \n';
    fprintf(fid, formatSpec);

    formatSpec  ='D,ALL,ALL   \n';
    fprintf(fid, formatSpec);

    formatSpec  ='SAVE  \n';
    fprintf(fid, formatSpec);
    
    formatSpec  ='FINI   \n';
    fprintf(fid, formatSpec);
    
    formatSpec  ='/SOLUTION   \n';
    fprintf(fid, formatSpec);
    
    formatSpec  ='SOLVE   \n';
    fprintf(fid, formatSpec);

    formatSpec  ='FINISH   \n';
    fprintf(fid, formatSpec);

    formatSpec  ='/POST1   \n';
    fprintf(fid, formatSpec);
    
    
    % List of dispacements
    formatSpec  ='DNSOL , %4u, U, X, %4u   \n';
    for i=1:numel(ShowUX)
        fprintf(fid, formatSpec,i,ShowUX(i));
    end
    formatSpec  ='DNSOL , %4u, U, Y, %4u   \n';
    for i=1:numel(ShowVY)
        fprintf(fid, formatSpec,i,ShowVY(i));
    end

    % List of stresses
    formatSpec   ='DESOL , %4u, %4u, S, X, %4u   \n';
    for i=1:size(ShowSX,1)    
        for j=1:size(ShowSX,2) 
            fprintf(fid, formatSpec,i,OutputTopology(i,j),ShowSX(i,j));
        end    
    end
    formatSpec   ='DESOL , %4u, %4u, S, Y, %4u   \n';
    for i=1:size(ShowSY,1)
        for j=1:size(ShowSX,2) 
            fprintf(fid, formatSpec,i,OutputTopology(i,j),ShowSY(i,j));
        end
    end
    formatSpec   ='DESOL , %4u, %4u , S, Z, %4u \n';
    for i=1:size(ShowSZ,1)
        for j=1:size(ShowSZ,2)
            fprintf(fid, formatSpec,i,OutputTopology(i,j),ShowSZ(i,j));
        end    
    end
    formatSpec   ='DESOL , %4u, %4u , S, XY, %4u   \n';
    for i=1:size(ShowTXY,1)
        for j=1:size(ShowTXY,2)
            fprintf(fid, formatSpec,i,OutputTopology(i,j),ShowTXY(i,j));
        end    
    end
    formatSpec   ='DESOL , %4u, %4u , S, XZ, %4u   \n';
    for i=1:size(ShowTXZ,1)
        for j=1:size(ShowTXZ,2)
            fprintf(fid, formatSpec,i,OutputTopology(i,j),ShowTXZ(i,j));      
        end    
    end
    formatSpec   ='DESOL , %4u, %4u , S, YZ, %4u  \n';
    for i=1:size(ShowTYZ,1)
        for j=1:size(ShowTYZ,2)
            fprintf(fid, formatSpec,i,OutputTopology(i,j),ShowTYZ(i,j));       
        end    
    end
    formatSpec   ='/GRAPHICS,FULL    \n';
    fprintf(fid, formatSpec);

    fclose(fid);
end

