%**************************************************************************
% This file is part of the MLS-C Library; you can redistribute it and/or 
% modify it under the terms of the GNU Lesser General Public License as 
% published by the Free Software Foundation; either version 3 of the 
% License,or any later version.
% This program is distributed in the hope that it will be useful but 
% WITHOUT ANY WARRANTY; without even the implied warranty of 
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General 
% Public License for more details.
% You should have received a copy of the GNU Lesser General Public License
% along with GNU; see the file COPYING.  If not, write to the Free Software
% Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
% or see <http://www.gnu.org/licenses/>.
%**************************************************************************
% Created by: 
%    E Nadal, M Ouallal, JJ Rodenas, F Chinesta and FJ Fuenmayor
%  
% Release 1.0  
% Date: 18/07/2014
%**************************************************************************
%%
function [RCoord,RStress]=RotationMatrices(Alpha,Dims)
% Evaluates rotation matrices for Coordinates and Stresses (or Stains)
% so that if we calculate 
%     Results = RMatrix*Data 
% Then Results are expressed in a refference system rotated Alpha rads 
% with respect to the coordinates system used to express Data
% Note: Alpha could be a vector. This could be used for rotations in 3-D
% 
% INPUT
% Alpha    = The angle of rotation
% Dims     = Dimensions
%
% OUTPUT 
% RCoord  = The coordinate rotation matrix
% RStress = The stress rotation matrix

if nargin<2
    Dims = 2;
end

switch Dims
    case 2 % 2-D
        CA  = cos(Alpha);
        SA  = sin(Alpha);
        S2A = sin(2*Alpha);
        
% Rotates points in the xy-Cartesian plane counter-clockwise
% through the angle Alpha about the origin of the Cartesian coordinate system.
        RCoord  = [...
                   CA , SA;...
                  -SA, CA];
            
        RStress = [...
                   CA^2     , SA^2    ,  S2A         ;...
                   SA^2     , CA^2    , -S2A         ;...
                  -0.5*S2A , 0.5*S2A ,  cos(2*Alpha)];
        return
% Only available for 2-D
    otherwise 
        disp (['Cannot create matrices to rotate in ',num2str(Dims),'-D']);
        error('stop');

end