%**************************************************************************
% This file is part of the MLS-C Library; you can redistribute it and/or 
% modify it under the terms of the GNU Lesser General Public License as 
% published by the Free Software Foundation; either version 3 of the 
% License,or any later version.
% This program is distributed in the hope that it will be useful but 
% WITHOUT ANY WARRANTY; without even the implied warranty of 
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General 
% Public License for more details.
% You should have received a copy of the GNU Lesser General Public License
% along with GNU; see the file COPYING.  If not, write to the Free Software
% Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
% or see <http://www.gnu.org/licenses/>.
%**************************************************************************
% Created by: 
%    E Nadal, M Ouallal, JJ Rodenas, F Chinesta and FJ Fuenmayor
%  
% Release 1.0  
% Date: 18/07/2014
%**************************************************************************
function [txty,tntt]=press(Curve,t,x,y,Angle)
% INPUT DATA:
%------------------
% Curve - Id. Curve (internal ID)
% t     - relative position of the point within the Curve
% x & y - x and y global coordinates of the point
% Angle - Angle of the normal to the surface at points
%
% OUTPUT DATA:
%------------------
% txty  - will be a 2x1 vector where:
%           txty(1) = tx
%           txty(2) = ty
%
%***************************************************************

GlobalCS=1;   %the tractions will be specified as {tx,ty}
LocalCS=0;    %the tractions will be specified as {tn,tt}
              %note: use t>0 for tractions and t<0 for compressions


switch Curve
    % @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
    % The user can make changes to define the pressure on boundary,
    % from here...
    
    % Different examples are given to define the pressure for each curve.
    
    case 1 
        CS=LocalCS;
        tn=-100;
        tt=   0;
        
%    case 2
%         CS=GlobalCS;
%         tx=-100;
%         ty=   0;

%     case 3
%         CS=LocalCS;
%         tn=-100*t;
%         tt= 0*t;

%     case 3
%         CS=LocalCS;
%         tn=-100*y;
%         tt= 0*t;
       

        % to here.
        % @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
    otherwise
        CS=GlobalCS;
        tx=0;
        ty=0;
end
% Change the coordinate system to global
if CS==LocalCS
    tntt=[tn;tt];
    txty =[cos(-Angle),sin(-Angle);-sin(-Angle),cos(-Angle)]*tntt;
elseif CS==GlobalCS
    [txty]=[tx;ty];
    tntt =[cos(Angle),sin(Angle);-sin(Angle),cos(Angle)]*txty;
end